"""
WillofSteel API Wrapper
~~~~~~~~~~~~~~~~~~~~~~~

A wrapper for the Will of Steel API

:copyright: (C) 2024-present ItsNeil
:license: MIT, see LICENSE for more details

"""

__title__ = "willofsteel"
__author__ = "ItsNeil"
__license__ = "MIT"
__copyright__ = "Copyright 2024-present ItsNeil"
__version__ = "0.0.1a"

from .wrapper import *